"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _vue = _interopRequireDefault(require("vue"));

var _vuexAlong = require("vuex-along");

var _router = _interopRequireDefault(require("./router"));

var _store = _interopRequireDefault(require("./store"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const HOOK_KEYS = Object.freeze({
  beforeEach: true,
  beforeResolve: true,
  afterEach: true,
  onReady: true,
  onError: true
});
var _default = {
  start(moduleConfig) {
    const application = moduleConfig.getApplication();
    const vuexAlong = {};
    vuexAlong.name = `vuexAlong:${application.name}-${application.version}`;
    const local = [];
    const session = [];
    let configs = moduleConfig.getExtension('vuex.modules');

    for (let key in configs) {
      const m = configs[key];

      _store.default.registerModule(key, m);

      if (m.storage) {
        if (m.storage === 'session') {
          session.push(key);
        } else if (m.storage === 'local') {
          local.push(key);
        }
      }
    }

    if (session.length > 0) {
      vuexAlong.session = {
        list: session
      };
    }

    if (local.length > 0) {
      vuexAlong.local = {
        list: local
      };
    } else {
      vuexAlong.justSession = true;
    }

    (0, _vuexAlong.createVuexAlong)(vuexAlong)(_store.default);
    configs = moduleConfig.getExtension('vue.plugins');

    for (let key in configs) {
      _vue.default.use(configs[key]);
    }

    const options = [];
    configs = moduleConfig.getExtension('vue.options');

    for (let key in configs) {
      options.push(configs[key]);
    }

    configs = moduleConfig.getExtension('vue.router.routes');
    const routes = [];
    const parentRoutes = {};
    const unresolved = {};

    function registerParentRoutes(route) {
      if (route.children !== undefined && Array.isArray(route.children)) {
        const name = route.name;

        if (name === undefined || name === '') {
          console.log(`Error: 路由名称未定义，${JSON.stringify(route)}`);
          return;
        }

        parentRoutes[name] = route.children;

        if (unresolved[name]) {
          unresolved[name].forEach(item => {
            route.children.push(item);
          });
          delete unresolved[name];
        }

        route.children.forEach(item => {
          registerParentRoutes(item);
        });
      }
    }

    for (const key in configs) {
      const config = configs[key];

      if (config && config.parent && config.routes) {
        const parentName = config.parent;
        let parent;

        if (parentName === 'root') {
          parent = routes;
        } else {
          parent = parentRoutes[parentName];

          if (parent === undefined) {
            unresolved[parentName] = unresolved[parentName] || [];
            parent = unresolved[parentName];
          }
        }

        config.routes.forEach(item => {
          parent.push(item);
          registerParentRoutes(item);
        });
      }
    }

    for (const key in unresolved) {
      console.log(`Error: 父路由“${key}”不存在`);
    }

    _router.default.addRoutes(routes);

    configs = moduleConfig.getExtension('vue.router.hooks');

    for (let key in configs) {
      const config = configs[key];

      for (let hook in config) {
        if (HOOK_KEYS[hook]) {
          _router.default[hook](config[hook]);
        }
      }
    }

    const app = moduleConfig.getExtension('vue.app');
    const vueOptions = {
      router: _router.default,
      store: _store.default,
      mixins: options,
      render: h => h(app.component)
    };
    new _vue.default(vueOptions).$mount('#app');
  }

};
exports.default = _default;